<?php
namespace Etn\Core\Attendee;
use Etn\Utils\Helper;

defined( 'ABSPATH' ) || exit;

class Attendee_List {
    use \Etn\Traits\Singleton;

    /**
     * Class constructor.
     */
    public function init() {
        add_filter( "manage_etn-attendee_posts_columns", [ $this, "attendee_post_columns" ] );
        add_action( "manage_etn-attendee_posts_custom_column", [ $this, 'attendee_custom_column' ], 10, 2 );

        //register cron-job depending on settings
        $settings = Helper::get_settings();
        $attendee_reg_enable = !empty( $settings["attendee_registration"] ) ? true : false;
        if( $attendee_reg_enable ){
            // Attendee cron job to remove attendee
            \Etn\Core\Attendee\Cron::instance()->init();
        }

        // hide preview , view , edit link
        add_filter( 'page_row_actions', [$this, 'remove_row_actions'], 10, 2 );

        // generate pdf
        add_action( 'init', [$this, 'generate_ticket_pdf'] );
        add_action( 'init', [$this, 'download_ticket_pdf_admin'] );
    }

    /**
     * Download PDF from email
     */
    public function generate_ticket_pdf() {

        if ( isset( $_POST['etn_download_attendee_action'] ) && sanitize_text_field( $_POST['etn_download_attendee_action'] ) !== '' ) {
            $post_arr = filter_input_array( INPUT_POST, FILTER_SANITIZE_FULL_SPECIAL_CHARS );

            if ( !empty( $post_arr["attendee_id"] ) ) {
                $user_id        = intval( $post_arr["attendee_id"] );
                $ticket_price   = $post_arr['etn_ticket_price'];
                $event_location = $post_arr['event_location'];
                $event_name     = $post_arr['event_name'];
                $start_date     = $post_arr['etn_start_date'];
                $end_date       = $post_arr['etn_end_date'];
                $start_time     = $post_arr['etn_start_time'];
                $end_time       = $post_arr['etn_end_time'];
                $attendee_name  = get_post_meta( $user_id, "etn_name", true );
                $attendee_email = get_post_meta( $user_id, "etn_email", true );
                $attendee_phone = get_post_meta( $user_id, "etn_phone", true );
                
                $this->generate_pdf($event_name, $start_date, $end_date, $start_time, $end_time, $event_location, $ticket_price, $attendee_name, $attendee_email, $attendee_phone);
            
            } else {
                wp_head();
                ?>
                <div class="section-inner">
                    <h3 class="entry-title">
                        <?php echo esc_html__( "Invalid data. ", "eventin" ); ?>
                    </h3>
                    <div class="intro-text">
                        <a href="<?php echo esc_url( home_url() ); ?>"><?php echo esc_html__( "Return to homepage", "eventin" ); ?></a>
                    </div>
                </div>
                <?php
                wp_footer();
            }
            exit;
        }

    }

    /**
     * Download PDF from admin
     */
    public function download_ticket_pdf_admin() {
        if ( isset( $_GET['download_ticket_admin'] ) ) {
        
            $get_arr = filter_input_array( INPUT_GET, FILTER_SANITIZE_FULL_SPECIAL_CHARS );

            if ( !empty( $get_arr["attendee_id"] ) ) {
                $user_id        = intval( $get_arr["attendee_id"] );
                $ticket_price   = $get_arr['etn_ticket_price'];
                $event_location = $get_arr['event_location'];
                $event_name     = $get_arr['event_name'];
                $start_date     = $get_arr['etn_start_date'];
                $end_date       = $get_arr['etn_end_date'];
                $start_time     = $get_arr['etn_start_time'];
                $end_time       = $get_arr['etn_end_time'];
                $attendee_name  = get_post_meta( $user_id, "etn_name", true );
                $attendee_email = get_post_meta( $user_id, "etn_email", true );
                $attendee_phone = get_post_meta( $user_id, "etn_phone", true );
                
                $this->generate_pdf($event_name, $start_date, $end_date, $start_time, $end_time, $event_location, $ticket_price, $attendee_name, $attendee_email, $attendee_phone);
            
            } else {
                wp_head();
                ?>
                <div class="section-inner">
                    <h3 class="entry-title">
                        <?php echo esc_html__( "Invalid data. ", "eventin" ); ?>
                    </h3>
                    <div class="intro-text">
                        <a href="<?php echo esc_url( home_url() ); ?>"><?php echo esc_html__( "Return to homepage", "eventin" ); ?></a>
                    </div>
                </div>
                <?php
                wp_footer();
            }
            exit;
        }

    }

    /**
     * Generate PDF file with provided data
     *
     * @param [type] $event_name
     * @param [type] $start_date
     * @param [type] $end_date
     * @param [type] $start_time
     * @param [type] $end_time
     * @param [type] $event_location
     * @param [type] $ticket_price
     * @param [type] $attendee_name
     * @param [type] $attendee_email
     * @param [type] $attendee_phone
     * @return void
     */
    public function generate_pdf( $event_name, $start_date, $end_date, $start_time, $end_time, $event_location, $ticket_price, $attendee_name, $attendee_email, $attendee_phone ) {
        
        $pdf_file_name = strtolower( str_replace( " ", "-", $attendee_name ) );
        $pdf           = new \Etn\Utils\FPDF();
        $pdf->AddPage();
        $pdf->SetFont( 'Arial', 'B', 16 );
        // html
        $pdf->Cell( 80, 15, esc_html__( "Event details:", "eventin" ), 0, 0, 'L', 0 );
        $pdf->ln();
        $pdf->SetFont( '', 'B', 10 );
        $pdf->Cell( 40, 5, esc_html__( "Event name:", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $event_name, 0, 1, 'L', 0 );
        $pdf->ln();

        $pdf->Cell( 40, 5, esc_html__( "Start date :", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $start_date, 0, 1, 'L', 0 );
        $pdf->Cell( 40, 5, esc_html__( "End date :", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $end_date, 0, 1, 'L', 0 );
        $pdf->ln();

        $pdf->Cell( 40, 5, esc_html__( "Start time :", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $start_time, 0, 1, 'L', 0 );
        $pdf->Cell( 40, 5, esc_html__( "End time :", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $end_time, 0, 1, 'L', 0 );
        $pdf->ln();
        $pdf->Cell( 40, 5, esc_html__( "Location:", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $event_location, 0, 1, 'L', 0 );
        $pdf->ln();
        $pdf->Cell( 40, 5, esc_html__( "Ticket price:", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $ticket_price, 0, 1, 'L', 0 );

        $pdf->SetFont( '', 'B', 16 );
        $pdf->Cell( 80, 15, esc_html__( "Attendee details:", "eventin" ), 0, 0, 'L', 0 );

        $pdf->SetFont( '', 'B', 10 );
        $pdf->ln();
        $pdf->Cell( 40, 5, esc_html__( "Name:", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $attendee_name, 0, 1, 'L', 0 );
        $pdf->ln();
        $pdf->Cell( 40, 5, esc_html__( "Email:", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $attendee_email, 0, 1, 'L', 0 );
        $pdf->ln();
        $pdf->Cell( 40, 5, esc_html__( "Phone:", "eventin" ), 0, 0, 'L', 0 );
        $pdf->Cell( 80, 5, $attendee_phone, 0, 1, 'L', 0 );

        $pdf->Output( "D", $pdf_file_name . ".pdf" );
    }

    /**
     * hide preview , view , edit link
     */
    public function remove_row_actions( $actions, $post ) {

        if ( $post->post_type === 'etn-attendee' ):
            unset( $actions['edit'] );
            unset( $actions['view'] );
            unset( $actions['inline hide-if-no-js'] );
        endif;
        return $actions;
    }

    /**
     * Column name
     */
    public function attendee_post_columns( $columns ) {
        unset( $columns['date'] );
        unset( $columns['title'] );

        $columns['id']                  = esc_html__( 'Id', 'eventin' );
        $columns['etn_name']            = esc_html__( 'Name', 'eventin' );
        $columns['etn_email']           = esc_html__( 'Email', 'eventin' );
        $columns['etn_phone']           = esc_html__( 'Phone', 'eventin' );
        $columns['etn_event']           = esc_html__( 'Event', 'eventin' );
        $columns['etn_status']          = esc_html__( 'Payment', 'eventin' );
        $columns['etn_download_ticket'] = esc_html__( 'Ticket', 'eventin' );

        return $columns;
    }

    /**
     * Return row
     */
    public function attendee_custom_column( $column, $post_id ) {

        $event_id           = get_post_meta( $post_id, 'etn_event_id', true );
        $attendee_name      = get_post_meta( $post_id, 'etn_name', true );
        $attendee_email     = get_post_meta( $post_id, 'etn_email', true );
        $attendee_phone     = get_post_meta( $post_id, 'etn_phone', true );
        $payment_status     = get_post_meta( $post_id, 'etn_status', true );
        $event_name         = get_the_title( $event_id );
        $event_location     = get_post_meta( $event_id, "etn_event_location", true );
        $event_start_date   = get_post_meta( $event_id, "etn_start_date", true );
        $event_end_date     = get_post_meta( $event_id, "etn_end_date", true );
        $event_start_time   = get_post_meta( $event_id, "etn_start_time", true );
        $event_end_time     = get_post_meta( $event_id, "etn_end_time", true );
        $event_ticket_price = get_post_meta( $event_id, "etn_ticket_price", true );

        switch ( $column ) {
        case 'id':
            echo intval( $post_id );
            break;
        case 'etn_name':
            echo esc_html( $attendee_name );
            break;
        case 'etn_email':
            echo esc_html( $attendee_email );
            break;
        case 'etn_phone':
            echo esc_html( $attendee_phone );
            break;
        case 'etn_event':
            echo esc_html( $event_name );
            break;
        case 'etn_status':
            echo esc_html( $payment_status );
            break;
        case 'etn_download_ticket':
            $action_url = home_url( );
            $attend_pdf_data  = array( 
                'event_name'        => $event_name , 
                'event_location'    => $event_location , 
                'etn_ticket_price'  => $event_ticket_price ,
                'etn_start_date'    => $event_start_date , 
                'etn_end_date'      => $event_end_date , 
                'etn_start_time'    => $event_start_time , 
                'etn_end_time'      => $event_end_time , 
                'attendee_id'       => $post_id
             );
            ?>
            <div class="etn-attendee-details-button-download">
                <?php 
                $query_string = "?download_ticket_admin=true";
                foreach ($attend_pdf_data as $key => $value) {
                    $query_string .= "&" . $key . "=" . $value;
                }
                ?>
                <a target="_blank" href="<?php echo esc_url( $action_url );?>/etn-attendee<?php echo esc_html( $query_string ); ?>" class="etn-btn etn-success download-details" ><?php  echo esc_html__('Download','eventin');?></a>
            </div>
            <?php
            break;
        }

    }

}
