<?php

namespace Etn\Core\Attendee;

use Etn\Utils\Helper;

defined( "ABSPATH" ) or die();

class InfoUpdate {

    use \Etn\Traits\Singleton;

    public function init() {
        add_action( 'init', [$this, 'attendee_info_update_process']);
        add_action( 'init', [$this, 'update_attendee_details']);
    }

    public function attendee_info_update_process() {
        $settings        = Helper::get_settings();
        $include_phone   = !empty( $settings["reg_require_phone"] ) ? true : false;
        $include_email   = !empty( $settings["reg_require_email"] ) ? true : false;

        if ( isset( $_POST["etn_update_attendee_action"] ) && isset( $_POST['attendee_id'] ) && isset( $_POST['etn_info_edit_token'] ) ) {
            $post_arr = filter_input_array( INPUT_POST, FILTER_SANITIZE_STRING );

            if ( !empty( $post_arr['attendee_id'] ) && !empty( $post_arr['etn_info_edit_token'] )) {
                $user_id      = is_numeric( $post_arr["attendee_id"] ) ? $post_arr["attendee_id"] : 0;
                $access_token = $post_arr['etn_info_edit_token'];

                global $wpdb;
                $attendee_data = $wpdb->get_results( "SELECT * FROM $wpdb->postmeta WHERE meta_key = 'etn_info_edit_token' AND meta_value = '$access_token' LIMIT 1", ARRAY_A );

                get_header(  );
                if ( isset( $attendee_data ) && is_array( $attendee_data ) && !empty( $attendee_data ) && ( $attendee_data[0]["post_id"] == $user_id ) ) {
                    $attendee_name  = get_post_meta( $user_id, "etn_name", true );
                    $attendee_email = get_post_meta( $user_id, "etn_email", true );
                    $attendee_phone = get_post_meta( $user_id, "etn_phone", true );

                    $base_url           = home_url( );
                    $attendee_cpt       = new \Etn\Core\Attendee\Cpt();
                    $attendee_endpoint  = $attendee_cpt->get_name();
                    $action_url         = $base_url . "/" . $attendee_endpoint;
                    ?>
                    <div class="etn-es-events-page-container">
                        <div class="etn-event-single-wrap">
                            <div class="etn-container">
                                <div class="etn-attendee-form">
                                     <h3 class="attendee-title"><?php echo esc_html__( "Update Attendee Details", "eventin" ); ?></h3>
                                    <form action="<?php echo esc_url( $action_url );?>" method="post" class="attende_form">
                                        <div class="etn-attendee-form-wrap">
                                            <div class="etn-name-field etn-group-field">
                                                <label for="etn_product_qty">
                                                    <?php echo esc_html__( 'Name', "eventin" ); ?>
                                                </label>
                                                <input class="attr-form-control" id="attendee_name" name="name" type="text" value="<?php echo esc_html( $attendee_name ); ?>" required/><span class="etn-input-field-required"> *</span>
                                                <div class="etn-error attendee_name"></div>   
                                            </div>
                                            <?php 
                                                if( $include_email ){
                                                    ?>
                                                    <div class="etn-email-field etn-group-field">
                                                        <label for="etn_product_qty">
                                                            <?php echo esc_html__( 'Email', "eventin" ); ?>
                                                        </label>
                                                        <input class="attr-form-control"  id="attendee_email" name="email" type="email" value="<?php echo esc_html( $attendee_email ); ?>" required/><span class="etn-input-field-required"> *</span>
                                                        <div class="etn-error attendee_email"></div>   
                                                    </div>
                                                    <?php
                                                }
                                                ?>
                                                <?php
                                                if( $include_phone ) {
                                                    ?>
                                                    <div class="etn-phone-field etn-group-field">
                                                        <label for="etn_product_qty">
                                                            <?php echo esc_html__( 'Phone', "eventin" ); ?>
                                                        </label>
                                                        <input class="attr-form-control" id="attendee_phone" name="phone" type="tel" value="<?php echo esc_html( $attendee_phone ); ?>" required/><span class="etn-input-field-required"> *</span>
                                                        <div class="etn-error attendee_phone"></div>   
                                                    </div>
                                                    <?php
                                                }
                                                ?>
                                        </div>
                                        <?php wp_nonce_field( 'attendee_details_nonce', 'attendee_personal_data' );?>
                                        <input name="etn_attendee_details_update_action" type="hidden" value="etn_attendee_details_update_action" required/>
                                        <input name="etn_attendee_id" type="hidden" value="<?php echo esc_html( $user_id ); ?>" required/>
                                        <input name="etn_info_edit_token" type="hidden" value="<?php echo esc_html( $access_token ); ?>" required/>
                                        <input name="submit" class="etn-btn etn-primary attendee_update_sumbit" type="submit" value="<?php echo esc_html__( "Update", "eventin" ); ?>" />
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
                } else {
                    ?>
                    <div class="etn-es-events-page-container">
                        <div class="etn-event-single-wrap">
                            <div class="etn-container">
                                <div class="etn-row">
                                    <h3><?php echo esc_html__( "Invalid Attendee Credentials", "eventin" ); ?></h3>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
                }
                get_footer(  );
                exit;
            }
        }
    }

    public function update_attendee_details() {

        if ( isset( $_POST["etn_attendee_details_update_action"] ) && $_POST["etn_attendee_details_update_action"] == "etn_attendee_details_update_action" ) {
            $post_arr = filter_input_array( INPUT_POST, FILTER_SANITIZE_STRING );  
            get_header();
            if ( !empty($post_arr["etn_attendee_id"]) && !empty($post_arr["name"]) ) {
                
                $attendee_id         = is_numeric( $post_arr["etn_attendee_id"] ) ? $post_arr["etn_attendee_id"] : 0;
                $attendee_name       = !empty( $post_arr["name"] ) ? $post_arr["name"] : "";
                $attendee_email      = !empty( $post_arr["email"] ) ? $post_arr["email"] : "";
                $attendee_phone      = !empty( $post_arr["phone"] ) ? $post_arr["phone"] : "";
                $attendee_edit_token = $post_arr["etn_info_edit_token"];

                global $wpdb;
                $attendee_data = $wpdb->get_results( "SELECT * FROM $wpdb->postmeta WHERE meta_key = 'etn_info_edit_token' AND meta_value = '$attendee_edit_token' LIMIT 1", ARRAY_A );

                if ( isset( $attendee_data ) && is_array( $attendee_data ) && !empty( $attendee_data ) && ( $attendee_data[0]["post_id"] == $attendee_id ) ) {
                    update_post_meta( $attendee_id, "etn_name", $attendee_name );
                    update_post_meta( $attendee_id, "etn_email", $attendee_email );
                    update_post_meta( $attendee_id, "etn_phone", $attendee_phone );
                    $attendee_post = array(
                        'ID'           => $attendee_id,
                        'post_title'   => $attendee_name,
                    );
                    
                    // Update the post into the database
                    wp_update_post( $attendee_post );
                    ?>
                    <div class="etn-es-events-page-container">
                        <div class="etn-event-single-wrap">
                            <div class="etn-container">
                                <div class="section-inner">
                                    <h3 class="entry-title">
                                        <?php echo esc_html__("Attendee details updated", "eventin");?>
                                    </h3>
                                    <div class="intro-text">
                                        <a href="<?php echo esc_url( home_url() );?>"><?php echo esc_html__("Return to homepage", "eventin"); ?></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
                }
            } else {
                    ?>
                    <div class="etn-es-events-page-container">
                        <div class="etn-event-single-wrap">
                            <div class="etn-container">
                                <div class="section-inner">
                                    <h3 class="entry-title">
                                        <?php echo esc_html__("Invalid data. Make sure no required data is missing.", "eventin");?>
                                    </h3>
                                    <div class="intro-text">
                                        <a href="<?php echo esc_url( home_url() );?>"><?php echo esc_html__("Return to homepage", "eventin"); ?></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
            }
            get_footer(  );
            exit;
        }
    }

}
