<?php

namespace Etn\Core\Event;

use Etn\Utils\Helper;

defined("ABSPATH") or die();

class Registration{

    use \Etn\Traits\Singleton;

    /**
     * Call all necessary hook 
     */
    public function init(){
        add_action('init', [ $this, 'registration_step_two']);
    }

    /**
     * Store attendee report
     */
    public function registration_step_two(){
        if ( isset( $_POST['ticket_purchase_next_step'] )  && $_POST['ticket_purchase_next_step'] === "two") {
            $post_arr        = filter_input_array( INPUT_POST, FILTER_SANITIZE_STRING );
            $check           = wp_verify_nonce( $post_arr['ticket_purchase_next_step_two'], 'ticket_purchase_next_step_two' );
            $settings        = Helper::get_settings();
            $include_phone   = !empty( $settings["reg_require_phone"] ) ? true : false;
            $include_email   = !empty( $settings["reg_require_email"] ) ? true : false;

            if( $check && !empty( $post_arr["quantity"] ) && !empty( $post_arr["event_id"] ) ){

                $total_qty = intval( $post_arr["quantity"] );
                $attendee_info_update_key = md5( md5( "etn-access-token" . time() . $total_qty ) );
                ?>
                <?php get_header(); ?>
                <div class="etn-es-events-page-container">
                    <div class="etn-event-single-wrap">
                        <div class="etn-container">
                           
                            <div class="etn-attendee-form">
                            <h3 class="attendee-title"><?php echo esc_html__("Attendee Details For ", "eventin") . esc_html( $post_arr["event_name"] );?></h3>

                                <form action="" method="post" id="etn-event-attendee-data-form" class="attende_form">
                                    <?php wp_nonce_field('ticket_purchase_next_step_three','ticket_purchase_next_step_three'); ?>
                                    <input name="ticket_purchase_next_step" type="hidden" value="three" />
                                    <input name="event_name" type="hidden" value="<?php echo esc_html( $post_arr["event_name"] ); ?>" />
                                    <input name="add-to-cart" type="hidden" value="<?php echo intval( $post_arr["event_id"] ); ?>" />
                                    <input name="quantity" type="hidden" value="<?php echo intval( $post_arr["quantity"] ); ?>" />
                                    <input name="attendee_info_update_key" type="hidden" value="<?php echo esc_html( $attendee_info_update_key ); ?>" />
                                    <?php
                                        for( $i = 1; $i <= $total_qty; $i++ ){
                                            ?>
                                            <div class="etn-attendee-form-wrap">
                                                <div class="etn-attendy-count">
                                                    <h4><?php echo esc_html__( "Attendee - ", "eventin" ) . $i; ?></h4>
                                                </div>
                                                <div class="etn-name-field etn-group-field">
                                                    <label for="etn_product_qty">
                                                        <?php echo esc_html__('Name', "eventin"); ?> <span class="etn-input-field-required">*</span>
                                                    </label>
                                                    <input class="attr-form-control" id="attendee_name_<?php echo intval($i)?>" name="attendee_name[]"  type="text"/>
                                                    <div class="etn-error attendee_name_<?php echo intval($i)?>"></div>   
                                                </div>
                                                <?php 
                                                if( $include_email ){
                                                    ?>
                                                    <div class="etn-email-field etn-group-field">
                                                        <label for="etn_product_qty">
                                                            <?php echo esc_html__('Email', "eventin"); ?><span class="etn-input-field-required"> *</span>
                                                        </label>
                                                        <input class="attr-form-control" id="attendee_email_<?php echo intval($i)?>" name="attendee_email[]" type="email"/>
                                                        <div class="etn-error attendee_email_<?php echo intval($i)?>"></div>   
                                                    </div>
                                                    <?php
                                                }
                                                ?>
                                                <?php
                                                if( $include_phone ) {
                                                    ?>
                                                    <div class="etn-phone-field etn-group-field">
                                                        <label for="etn_product_qty">
                                                            <?php echo esc_html__('Phone', "eventin"); ?><span class="etn-input-field-required"> *</span>
                                                        </label>
                                                        <input class="attr-form-control" maxlength="15" id="attendee_phone_<?php echo intval($i)?>" name="attendee_phone[]" type="tel"/>
                                                        <div class="etn-error attendee_phone_<?php echo intval($i)?>"></div>   
                                                    </div>
                                                    <?php
                                                }
                                                ?>
                                            </div>
                                            <?php
                                        }
                                    ?>
                                    <input name="submit" class="etn-btn etn-primary attendee_sumbit" type="submit" value="<?php echo esc_html__("Confirm", "eventin");?>" />
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
                <?php get_footer();
            } else {
                wp_redirect( get_permalink() );
            }
        }
        return false;
    }
}