<?php

namespace Etn\Utils;

defined( 'ABSPATH' ) || exit;
/**
 * Global helper class.
 *
 * @since 1.0.0
 */

class Helper {

    /**
     * Get etn older version if has any.
     *
     * @since 1.0.0
     * @access public
     */
    public static function old_version() {
        $version = get_option( 'etn_version' );
        return null == $version ? -1 : $version;
    }

    /**
     * Set metform installed version as current version.
     *
     * @since 1.0.0
     * @access public
     */
    public static function set_version() {
    }

    /**
     * Auto generate classname from path.
     *
     * @since 1.0.0
     * @access public
     */
    public static function make_classname( $dirname ) {
        $dirname    = pathinfo( $dirname, PATHINFO_FILENAME );
        $class_name = explode( '-', $dirname );
        $class_name = array_map( 'ucfirst', $class_name );
        $class_name = implode( '_', $class_name );
        return $class_name;
    }

    /**
     * Loads google fonts
     *
     * @param array $font_families
     * @return void
     */
    public static function google_fonts( $font_families = [] ) {
        $fonts_url = '';

        if ( $font_families ) {
            $query_args = [
                'family' => urlencode( implode( '|', $font_families ) ),
            ];

            $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
        }

        return esc_url_raw( $fonts_url );
    }

    /**
     * Renders provided markup
     *
     * @param [type] $content
     * @return void
     */
    public static function render( $content ) {
        return $content;
    }

    /**
     * Filters only accepted kses
     *
     * @param [type] $raw
     * @return void
     */
    public static function kses( $raw ) {
        $allowed_tags = [
            'a'                             => [
                'class'  => [],
                'href'   => [],
                'rel'    => [],
                'title'  => [],
                'target' => [],
            ],
            'input'                         => [
                'value'              => [],
                'type'               => [],
                'size'               => [],
                'name'               => [],
                'checked'            => [],
                'data-value'         => [],
                'data-default-color' => [],
                'placeholder'        => [],
                'id'                 => [],
                'class'              => [],
                'min'                => [],
                'step'               => [],
                'readonly'           => 'readonly',
            ],
            'button'                        => [
                'type'    => [],
                'name'    => [],
                'id'      => [],
                'class'   => [],
                'onclick' => [],
            ],
            'select'                        => [
                'value'       => [],
                'type'        => [],
                'size'        => [],
                'name'        => [],
                'placeholder' => [],
                'id'          => [],
                'class'       => [],
                'option'      => [
                    'value'   => [],
                    'checked' => [],
                ],
            ],
            'textarea'                      => [
                'value'       => [],
                'type'        => [],
                'size'        => [],
                'name'        => [],
                'rows'        => [],
                'cols'        => [],
                'placeholder' => [],
                'id'          => [],
                'class'       => [],
            ],
            'abbr'                          => [
                'title' => [],
            ],
            'b'                             => [],
            'blockquote'                    => [
                'cite' => [],
            ],
            'cite'                          => [
                'title' => [],
            ],
            'code'                          => [],
            'del'                           => [
                'datetime' => [],
                'title'    => [],
            ],
            'dd'                            => [],
            'div'                           => [
                'class' => [],
                'title' => [],
                'style' => [],
            ],
            'dl'                            => [],
            'dt'                            => [],
            'em'                            => [],
            'h1'                            => [
                'class' => [],
            ],
            'h2'                            => [
                'class' => [],
            ],
            'h3'                            => [
                'class' => [],
            ],
            'h4'                            => [
                'class' => [],
            ],
            'h5'                            => [
                'class' => [],
            ],
            'h6'                            => [
                'class' => [],
            ],
            'i'                             => [
                'class' => [],
            ],
            'img'                           => [
                'alt'    => [],
                'class'  => [],
                'height' => [],
                'src'    => [],
                'width'  => [],
            ],
            'li'                            => [
                'class' => [],
            ],
            'ol'                            => [
                'class' => [],
            ],
            'p'                             => [
                'class' => [],
            ],
            'q'                             => [
                'cite'  => [],
                'title' => [],
            ],
            'span'                          => [
                'class' => [],
                'title' => [],
                'style' => [],
            ],
            'iframe'                        => [
                'width'       => [],
                'height'      => [],
                'scrolling'   => [],
                'frameborder' => [],
                'allow'       => [],
                'src'         => [],
            ],
            'strike'                        => [],
            'br'                            => [],
            'strong'                        => [],
            'data-wow-duration'             => [],
            'data-wow-delay'                => [],
            'data-wallpaper-options'        => [],
            'data-stellar-background-ratio' => [],
            'ul'                            => [
                'class' => [],
            ],
            'label'                         => [
                'class'      => [],
                'for'        => [],
                'data-left'  => [],
                'data-right' => [],
            ],
            'form'                          => [
                'class'      => [],
                'id'        => [],
                'role'  => [],
                'action' => [],
                'method' => [],
            ]
        ];

        if ( function_exists( 'wp_kses' ) ) { // WP is here
            return wp_kses( $raw, $allowed_tags );
        } else {
            return $raw;
        }

    }

    /**
     * internal
     *
     * @param [type] $text
     * @return void
     */
    public static function kspan( $text ) {
        return str_replace( ['{', '}'], ['<span>', '</span>'], self::kses( $text ) );
    }

    /**
     * retuns trimmed word
     *
     * @param [type] $text
     * @param [type] $num_words
     * @return void
     */
    public static function trim_words( $text, $num_words ) {
        return wp_trim_words( $text, $num_words, '' );
    }

    public static function array_push_assoc( $array, $key, $value ) {
        $array[$key] = $value;
        return $array;
    }

    public static function img_meta( $id ) {
        $attachment = get_post( $id );

        if ( $attachment == null || $attachment->post_type != 'attachment' ) {
            return null;
        }

        return [
            'alt'         => get_post_meta( $attachment->ID, '_wp_attachment_image_alt', true ),
            'caption'     => $attachment->post_excerpt,
            'description' => $attachment->post_content,
            'href'        => get_permalink( $attachment->ID ),
            'src'         => $attachment->guid,
            'title'       => $attachment->post_title,
        ];
    }

    public static function datepicker_formats( $translate = null ) {
        $formats = [
            0     => 'Y-m-d',
            1     => 'n/j/Y',
            2     => 'm/d/Y',
            3     => 'j/n/Y',
            4     => 'd/m/Y',
            5     => 'n-j-Y',
            6     => 'm-d-Y',
            7     => 'j-n-Y',
            8     => 'd-m-Y',
            9     => 'Y.m.d',
            10    => 'm.d.Y',
            11    => 'd M Y',
            'm0'  => 'Y-m',
            'm1'  => 'n/Y',
            'm2'  => 'm/Y',
            'm3'  => 'n/Y',
            'm4'  => 'm/Y',
            'm5'  => 'n-Y',
            'm6'  => 'm-Y',
            'm7'  => 'n-Y',
            'm8'  => 'm-Y',
            'm9'  => 'Y.m',
            'm10' => 'm.Y',
            'm11' => 'm.Y',
        ];

        if ( is_null( $translate ) ) {
            return $formats;
        }

        return isset( $formats[$translate] ) ? $formats[$translate] : $formats[1];
    }

    public static function datetime_from_format( $format, $date ) {
        $keys = [
            // Year with 4 Digits
            'Y' => [ 'year', '\d{4}' ],

            // Year with 2 Digits
            'y' => [ 'year', '\d{2}' ],

            // Month with leading 0
            'm' => [ 'month', '\d{2}' ],

            // Month without the leading 0
            'n' => [ 'month', '\d{1,2}' ],

            // Month ABBR 3 letters
            'M' => [ 'month', '[A-Z][a-z]{2}' ],

            // Month Name
            'F' => [ 'month', '[A-Z][a-z]{2,8}' ],

            // Day with leading 0
            'd' => [ 'day', '\d{2}' ],

            // Day without leading 0
            'j' => [ 'day', '\d{1,2}' ],

            // Day ABBR 3 Letters
            'D' => [ 'day', '[A-Z][a-z]{2}' ],

            // Day Name
            'l' => [ 'day', '[A-Z][a-z]{5,8}' ],

            // Hour 12h formatted, with leading 0
            'h' => [ 'hour', '\d{2}' ],

            // Hour 24h formatted, with leading 0
            'H' => [ 'hour', '\d{2}' ],

            // Hour 12h formatted, without leading 0
            'g' => [ 'hour', '\d{1,2}' ],

            // Hour 24h formatted, without leading 0
            'G' => [ 'hour', '\d{1,2}' ],

            // Minutes with leading 0
            'i' => [ 'minute', '\d{2}' ],

            // Seconds with leading 0
            's' => [ 'second', '\d{2}' ],
        ];

        $date_regex = "/{$keys['Y'][1]}-{$keys['m'][1]}-{$keys['d'][1]}( {$keys['H'][1]}:{$keys['i'][1]}:{$keys['s'][1]})?$/";

		// if the date is already in Y-m-d or Y-m-d H:i:s, just return it
        if ( preg_match( $date_regex, $date ) ) {
            return $date;
        }

        // Convert format string to regex
        $regex = '';
        $chars = str_split( $format );

        foreach ( $chars as $n => $char ) {
            $last_char    = isset( $chars[$n - 1] ) ? $chars[$n - 1] : '';
            $skip_current = '\\' == $last_char;

            if ( !$skip_current && isset( $keys[$char] ) ) {
                $regex .= '(?P<' . $keys[$char][0] . '>' . $keys[$char][1] . ')';
            } elseif ( '\\' == $char ) {
                $regex .= $char;
            } else {
                $regex .= preg_quote( $char );
            }

        }

        $dt = [];

		// Now try to match it
        if ( preg_match( '#^' . $regex . '$#', $date, $dt ) ) {

			// Remove unwanted Indexes
            foreach ( $dt as $k => $v ) {
                if ( is_int( $k ) ) {
                    unset( $dt[$k] );
                }

            }

			// We need at least Month + Day + Year to work with
            if ( !checkdate( $dt['month'], $dt['day'], $dt['year'] ) ) {
                return false;
            }

        } else {
            return false;
        }

        $dt['month'] = str_pad( $dt['month'], 2, '0', STR_PAD_LEFT );
        $dt['day']   = str_pad( $dt['day'], 2, '0', STR_PAD_LEFT );

        $formatted = '{year}-{month}-{day}' . ( isset( $dt['hour'], $dt['minute'], $dt['second'] ) ? ' {hour}:{minute}:{second}' : '' );
        foreach ( $dt as $key => $value ) {
            $formatted = str_replace( '{' . $key . '}', $value, $formatted );
        }

        return $formatted;
    }

    public static function get_date_formats() {
        return [
            '0'  => 'Y-m-d',
            '1'  => 'n/j/Y',
            '2'  => 'm/d/Y',
            '3'  => 'j/n/Y',
            '4'  => 'd/m/Y',
            '5'  => 'n-j-Y',
            '6'  => 'm-d-Y',
            '7'  => 'j-n-Y',
            '8'  => 'd-m-Y',
            '9'  => 'Y.m.d',
            '10' => 'm.d.Y',
            '11' => 'd.m.Y',
            '11' => 'd M Y ',
        ];
    }

    public static function safe_path( $path ) {
        $path = str_replace( ['//', '\\\\'], ['/', '\\'], $path );
        return str_replace( ['/', '\\'], DIRECTORY_SEPARATOR, $path );
    }

    /**
     * Convert a multi-dimensional array into a single-dimensional array.
     * @author Sean Cannon, LitmusBox.com | seanc@litmusbox.com
     * @param  array $array The multi-dimensional array.
     * @return array
     */
    public static function array_flatten( $array ) {
        if ( !is_array( $array ) ) {
            return false;
        }

        $result = [];
        foreach ( $array as $key => $value ) {
            if ( is_array( $value ) ) {
                $result = array_merge( $result, self::array_flatten( $value ) );
            } else {
                $result = array_merge( $result, [ $key => $value ] );
            }

        }

        return $result;
    }

    /**
     * Post query to get data for widget and shortcode
     */
    public static function post_data_query( $post_type, $count = null, $order = null, $term_arr = null,
                                            $taxonomy_slug = null, $post__in = null, $post_not_in = null , $tag__in = null) {

        $data = [];
        $args = [
            'orderby'          => 'post_date',
            'post_type'        => $post_type,
            'post_status'      => 'publish',
            'suppress_filters' => false,
            'tax_query'         => array(
                'relation' => 'AND'
            )
        ];

        if ( $post_not_in != null ) {
            $args['post__not_in'] = $post_not_in;
        }

        if ( $count != null ) {
            $args['posts_per_page'] = $count;
        }

        if ( $order != null ) {
            $args['order'] = $order;
        }

        if ( $post__in != null ) {
            $args['post__in'] = $post__in;
        }

        // Elementor::If categories selected, add them to tax_query
        if(is_array( $term_arr ) && !empty( $term_arr )){
            $categories = array(
                'taxonomy' => $taxonomy_slug,
                'terms'    => $term_arr,
                'field'    => 'id',
                'include_children' => true,
                'operator'         => 'IN',
            );
            array_push($args['tax_query'], $categories);
        }

        // Elementor::If tags selected, add them to tax_query
        if(is_array( $tag__in ) && !empty( $tag__in )){
            $tags = array(
                'taxonomy' => 'etn_tags',
                'terms'    => $tag__in,
                'field'    => 'id',
                'include_children' => true,
                'operator'         => 'IN',
            );
            array_push($args['tax_query'], $tags);
        }

        // Settings::If hide Expired event is checked, filter out the expired events
        if ( !empty( get_option( "etn_event_options" )['checked_expired_event'] ) 
                && get_option( "etn_event_options" )['checked_expired_event'] == 'on' 
                && $post_type == "etn") {
            $args['meta_query'] = [
                'relation' => 'OR',
                [
                    'key'     => 'etn_end_date',
                    'value'   => date( 'Y-m-d' ),
                    'compare' => '>',
                ],
                [
                    'key'     => 'etn_end_date',
                    'value'   => '',
                    'compare' => '=',
                ],
            ];
        }

        $data = get_posts( $args );
        return $data;
    }

    public static function get_zoom_meetings( $meeting_id = null ) {
        $return_zoom_meetings = [];
        try {
            if ( is_null( $meeting_id ) ) {
                $meetings = get_posts( [
                    'post_type' => 'etn-zoom-meeting',
                ] );
                foreach ( $meetings as $meeting ) {
                    $return_zoom_meetings[$meeting->ID] = $meeting->post_title;
                }

                return $return_zoom_meetings;
            } else {
                // return single meeting

            }

        } catch ( \Exception $es ) {
            return [];
        }

    }

    public static function get_settings(){
        return get_option("etn_event_options");
    }

}
